Module timer

Module timer 

Timer module for periodic event generation

This module provides functionality for spawning timer tasks that periodically generate events, similar to Apama’s on wait(period).

Structs

TimerManager
Timer manager that tracks spawned timer tasks

Functions

spawn_timer
Spawn a timer task that periodically sends timer events