pub struct PartitionedSessionWindow { /* private fields */ }Expand description
A partitioned session window that maintains separate sessions per partition key
Implementations
Sourceimpl PartitionedSessionWindow
impl PartitionedSessionWindow
pub fn new(partition_key: String, gap: Duration) -> Self
Add a shared event to the appropriate partition session.
Sourcepub fn check_expired(
&mut self,
now: DateTime<Utc>,
) -> Vec<(String, Vec<SharedEvent>)>
pub fn check_expired( &mut self, now: DateTime<Utc>, ) -> Vec<(String, Vec<SharedEvent>)>
Check all partitions for expired sessions. Returns a list of (partition_key, events) for each expired session, and removes those partitions from the map.
Flush all partition sessions as SharedEvent references.
Sourcepub fn flush(&mut self) -> Vec<Event>
pub fn flush(&mut self) -> Vec<Event>
Flush all partition sessions (clones for backward compatibility).
Sourcepub fn checkpoint(&self) -> WindowCheckpoint
pub fn checkpoint(&self) -> WindowCheckpoint
Create a checkpoint of all partition sessions.
Sourcepub fn restore(&mut self, cp: &WindowCheckpoint)
pub fn restore(&mut self, cp: &WindowCheckpoint)
Restore partition sessions from a checkpoint.
Sourcepub fn advance_watermark(
&mut self,
wm: DateTime<Utc>,
) -> Vec<(String, Vec<SharedEvent>)>
pub fn advance_watermark( &mut self, wm: DateTime<Utc>, ) -> Vec<(String, Vec<SharedEvent>)>
Advance watermark — close expired sessions across all partitions.