pub struct PartitionedTumblingWindow { /* private fields */ }Expand description
A partitioned tumbling window that maintains separate windows per partition key
Implementations
Sourceimpl PartitionedTumblingWindow
impl PartitionedTumblingWindow
pub fn new(partition_key: String, duration: Duration) -> Self
Add a shared event to the appropriate partition window.
Flush all partition windows as SharedEvent references.
Sourcepub fn flush(&mut self) -> Vec<Event>
pub fn flush(&mut self) -> Vec<Event>
Flush all partition windows (clones for backward compatibility).
Sourcepub fn checkpoint(&self) -> WindowCheckpoint
pub fn checkpoint(&self) -> WindowCheckpoint
Create a checkpoint of all partition windows.
Sourcepub fn restore(&mut self, cp: &WindowCheckpoint)
pub fn restore(&mut self, cp: &WindowCheckpoint)
Restore partition windows from a checkpoint.
Sourcepub fn advance_watermark(
&mut self,
wm: DateTime<Utc>,
) -> Vec<(String, Vec<SharedEvent>)>
pub fn advance_watermark( &mut self, wm: DateTime<Utc>, ) -> Vec<(String, Vec<SharedEvent>)>
Advance watermark across all partitions.