pub struct SlidingWindow { /* private fields */ }Expand description
A sliding window that maintains overlapping windows
Implementations
Sourceimpl SlidingWindow
impl SlidingWindow
pub const fn new(window_size: Duration, slide_interval: Duration) -> Self
Add a shared event, returning window contents if slide interval reached.
Get current window contents as shared references.
Sourcepub fn current(&self) -> Vec<Event>
pub fn current(&self) -> Vec<Event>
Get current window contents (clones for backward compatibility).
Sourcepub fn checkpoint(&self) -> WindowCheckpoint
pub fn checkpoint(&self) -> WindowCheckpoint
Create a checkpoint of the current window state.
Sourcepub fn restore(&mut self, cp: &WindowCheckpoint)
pub fn restore(&mut self, cp: &WindowCheckpoint)
Restore window state from a checkpoint.
Sourcepub fn advance_watermark(
&mut self,
wm: DateTime<Utc>,
) -> Option<Vec<SharedEvent>>
pub fn advance_watermark( &mut self, wm: DateTime<Utc>, ) -> Option<Vec<SharedEvent>>
Advance watermark — emit window if slide interval has passed relative to watermark.