pub struct WorkerPool { /* private fields */ }Expand description
A pool of workers for parallel event processing
Implementations
Sourceimpl WorkerPool
impl WorkerPool
Sourcepub fn new<F>(config: WorkerPoolConfig, processor: F) -> Self
pub fn new<F>(config: WorkerPoolConfig, processor: F) -> Self
Create a new worker pool with the given configuration
Sourcepub async fn submit(
&self,
event: Event,
partition_key: &str,
) -> Result<(), PoolBackpressureError>
pub async fn submit( &self, event: Event, partition_key: &str, ) -> Result<(), PoolBackpressureError>
Submit an event to the pool with a partition key
Sourcepub fn queue_depth(&self) -> usize
pub fn queue_depth(&self) -> usize
Get current queue depth
Sourcepub async fn metrics(&self) -> WorkerPoolMetrics
pub async fn metrics(&self) -> WorkerPoolMetrics
Get pool metrics
Sourcepub async fn worker_statuses(&self) -> Vec<WorkerStatus>
pub async fn worker_statuses(&self) -> Vec<WorkerStatus>
Get status of all workers
Sourcepub const fn config(&self) -> &WorkerPoolConfig
pub const fn config(&self) -> &WorkerPoolConfig
Get pool configuration