pub struct PerSourceWatermarkTracker { /* private fields */ }Expand description
Tracks watermarks for multiple event sources.
The effective watermark is the minimum watermark across all registered sources, ensuring no source’s events are prematurely considered late.
Implementations
Sourceimpl PerSourceWatermarkTracker
impl PerSourceWatermarkTracker
Sourcepub fn register_source(&mut self, name: &str, max_ooo: Duration)
pub fn register_source(&mut self, name: &str, max_ooo: Duration)
Register a source with its maximum out-of-orderness tolerance.
Sourcepub fn observe_event(&mut self, source: &str, event_ts: DateTime<Utc>)
pub fn observe_event(&mut self, source: &str, event_ts: DateTime<Utc>)
Observe an event from a source, updating its watermark.
Sourcepub const fn effective_watermark(&self) -> Option<DateTime<Utc>>
pub const fn effective_watermark(&self) -> Option<DateTime<Utc>>
Get the effective (minimum) watermark across all sources.
Sourcepub fn advance_source_watermark(&mut self, source: &str, wm: DateTime<Utc>)
pub fn advance_source_watermark(&mut self, source: &str, wm: DateTime<Utc>)
Manually advance a source’s watermark (e.g., from upstream context).
Sourcepub fn checkpoint(&self) -> WatermarkCheckpoint
pub fn checkpoint(&self) -> WatermarkCheckpoint
Create a checkpoint of the tracker state.
Sourcepub fn restore(&mut self, cp: &WatermarkCheckpoint)
pub fn restore(&mut self, cp: &WatermarkCheckpoint)
Restore tracker state from a checkpoint.
Sourcepub fn has_sources(&self) -> bool
pub fn has_sources(&self) -> bool
Check if any sources are registered.